Welcome to oedisi's documentation!
=====================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started.rst
   examples.rst
   design.rst
   oedisi_cli.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
